"use strict";
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * @author Jorge Bay Gondra
 */
const utils = __importStar(require("../utils.cjs"));
const emptyMap = Object.freeze(new utils.ImmutableMap());
/**
 * Represents the response returned from the execution of a Gremlin traversal or script.
 */
class ResultSet {
    items;
    attributes;
    length;
    /**
     * Creates a new instance of {@link ResultSet}.
     * @param {Array} items
     * @param {Map} [attributes]
     */
    constructor(items, attributes) {
        this.items = items;
        if (!Array.isArray(items)) {
            throw new TypeError('items must be an Array instance');
        }
        this.items = items;
        /**
         * Gets a Map representing the attributes of the response.
         * @type {Map}
         */
        this.attributes = attributes || emptyMap;
        /**
         * Gets the amount of items in the result.
         * @type {Number}
         */
        this.length = items.length;
    }
    /**
     * Gets the iterator associated with this instance.
     * @returns {Iterator}
     */
    [Symbol.iterator]() {
        return this.items[Symbol.iterator]();
    }
    /**
     * Gets an array of result items.
     * @returns {Array}
     */
    toArray() {
        return this.items;
    }
    /**
     * Returns the first item.
     * @returns {Object|null}
     */
    first() {
        const item = this.items[0];
        return item !== undefined ? item : null;
    }
}
exports.default = ResultSet;
